@@ -88,7 +88,7 @@ int main(void)
   fh = mod_file_open("new.cif", "w");
   if (fh) {
     mod_selection_all(mdl, &sel1, &nsel1);
-    mod_model_write(mdl, libs, sel1, nsel1, fh, "MMCIF", 0, 1, &ierr);
+    mod_model_write(mdl, libs, sel1, nsel1, fh, "MMCIF", 0, 1, "", &ierr);
     g_free(sel1);
     mod_file_close(fh, &ierr);
   } else {
