@@ -7,23 +7,30 @@ try:
 except ImportError:
     import pickle
 
+
 class TransferFile(object):
     """Object used to transfer a file between Communicators"""
     def __init__(self, filename):
         self._filename = filename
 
+
 class HeartBeat:
     pass
 
+
 class DataType:
     desc = "generic data"
+
     def recv(self, buffer):
         pass
+
     def send(self, obj):
         pass
+
     def __str__(self):
         return self.desc
 
+
 if sys.version_info[0] >= 3:
     def _raw_byte_code(s):
         # Cannot simply use b'foo' since that is invalid syntax in Python 2.3
@@ -39,10 +46,12 @@ if sys.version_info[0] >= 3:
         code = _raw_byte_code('S')
         obj = str
         desc = "string"
+
         def recv(self, buffer):
             p = xdrlib.Unpacker(buffer[1:])
             obj = p.unpack_string().decode('UTF8')
             return (obj, buffer[1+p.get_position():])
+
         def send(self, obj):
             p = xdrlib.Packer()
             p.pack_string(obj.encode('UTF8'))
@@ -52,36 +61,44 @@ else:
         code = _raw_byte_code('S')
         obj = str
         desc = "string"
+
         def recv(self, buffer):
             p = xdrlib.Unpacker(buffer[1:])
             obj = p.unpack_string()
             return (obj, buffer[1+p.get_position():])
+
         def send(self, obj):
             p = xdrlib.Packer()
             p.pack_string(obj)
             return self.code + p.get_buffer()
 
+
 class NetInteger(DataType):
     code = _raw_byte_code('I')
     obj = int
     desc = "integer"
+
     def recv(self, buffer):
         p = xdrlib.Unpacker(buffer[1:])
         obj = p.unpack_int()
         return (obj, buffer[1+p.get_position():])
+
     def send(self, obj):
         p = xdrlib.Packer()
         p.pack_int(obj)
         return self.code + p.get_buffer()
 
+
 class NetFloat(DataType):
     code = _raw_byte_code('F')
     obj = float
     desc = "floating point"
+
     def recv(self, buffer):
         p = xdrlib.Unpacker(buffer[1:])
         obj = p.unpack_float()
         return (obj, buffer[1+p.get_position():])
+
     def send(self, obj):
         try:
             p = xdrlib.Packer()
@@ -92,14 +109,18 @@ class NetFloat(DataType):
         except SystemError:
             return NetPickle.send(obj)
 
+
 class NetPickle(DataType):
     code = _raw_byte_code('P')
     obj = None
+
     desc = "Python pickled object"
+
     def recv(self, buffer):
         p = xdrlib.Unpacker(buffer[1:])
         obj = p.unpack_string()
         return (pickle.loads(obj), buffer[1+p.get_position():])
+
     def send(self, obj):
         p = xdrlib.Packer()
         try:
@@ -110,10 +131,12 @@ class NetPickle(DataType):
             p.pack_string(pickle.dumps(obj, 0))
         return self.code + p.get_buffer()
 
+
 class NetFile(DataType):
     code = _raw_byte_code('f')
     obj = TransferFile
     desc = "Transferred file"
+
     def recv(self, buffer):
         filename, buffer = NetString.recv(buffer[1:])
         filelen, buffer = NetInteger.recv(buffer)
@@ -123,17 +146,20 @@ class NetFile(DataType):
         f = open(filename, 'wb')
         f.write(buffer[:filelen])
         return TransferFile(filename), buffer[filelen:]
+
     def send(self, obj):
         filename = obj._filename
         f = open(filename, 'rb')
         buf = f.read()
-        return self.code + NetString.send(filename) \
-               + NetInteger.send(len(buf)) + buf
+        return (self.code + NetString.send(filename)
+                + NetInteger.send(len(buf)) + buf)
+
 
 class NetCommand(NetString):
     code = _raw_byte_code('C')
     desc = "command"
 
+
 typemap = {}
 cmdmap = {}
 for name in dir():
